@@ -338,7 +338,7 @@ panel_ditem_editor_set_property (GObject       *object,
 }
 
 static void
-panel_ditem_editor_destroy (GtkObject *object)
+panel_ditem_editor_dispose (GObject *object)
 {
 	PanelDItemEditor *dialog;
 	
@@ -366,20 +366,18 @@ panel_ditem_editor_destroy (GtkObject *object)
 		g_free (dialog->priv->uri);
 	dialog->priv->uri = NULL;
 
-	GTK_OBJECT_CLASS (panel_ditem_editor_parent_class)->destroy (object);
+	G_OBJECT_CLASS (panel_ditem_editor_parent_class)->dispose (object);
 }
 
 static void
 panel_ditem_editor_class_init (PanelDItemEditorClass *class)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (class);
-	GtkObjectClass *gtkobject_class = GTK_OBJECT_CLASS (class);
 
 	gobject_class->constructor = panel_ditem_editor_constructor;
 	gobject_class->get_property = panel_ditem_editor_get_property;
         gobject_class->set_property = panel_ditem_editor_set_property;
-
-	gtkobject_class->destroy = panel_ditem_editor_destroy;
+        gobject_class->dispose = panel_ditem_editor_dispose;
 
 	g_type_class_add_private (class,
 				  sizeof (PanelDItemEditorPrivate));
@@ -608,8 +606,6 @@ panel_ditem_editor_make_ui (PanelDItemEditor *dialog)
 	dialog_vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 	gtk_box_set_spacing (GTK_BOX (dialog_vbox), 2);
 
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-
 	priv->table = gtk_table_new (4, 3, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (priv->table), 5);
 	gtk_table_set_row_spacings (GTK_TABLE (priv->table), 6);
