@@ -40,7 +40,6 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gdk/gdkkeysyms.h>
-#include <gconf/gconf-client.h>
 #include <gmenu-tree.h>
 
 #include <libgnome-desktop/gnome-desktop-utils.h>
@@ -52,23 +51,23 @@
 #include <libpanel-util/panel-show.h>
 
 #include "nothing.h"
-#include "panel-gconf.h"
 #include "panel-util.h"
 #include "panel-globals.h"
 #include "panel-enums.h"
-#include "panel-profile.h"
 #include "panel-stock-icons.h"
 #include "panel-multiscreen.h"
 #include "menu.h"
 #include "panel-lockdown.h"
 #include "panel-xutils.h"
 #include "panel-icon-names.h"
+#include "panel-schemas.h"
 
 typedef struct {
 	GtkWidget        *run_dialog;
 
+	GSettings        *run_settings;
+
 	GtkWidget        *main_box;
-	GtkWidget        *program_list_box;
 
 	GtkWidget        *combobox;
 	GtkWidget        *pixmap;
@@ -92,7 +91,6 @@ typedef struct {
 	int	          add_icons_idle_id;
 	int	          add_items_idle_id;
 	int		  find_command_idle_id;
-	int		  content_notify_id;
 	gboolean	  use_program_list;
 	gboolean	  completion_started;
 	
@@ -116,72 +114,64 @@ static PanelRunDialog *static_dialog = NULL;
 
 static void panel_run_dialog_disconnect_pixmap (PanelRunDialog *dialog);
 
-#define PANEL_RUN_HISTORY_KEY "/apps/gnome-settings/gnome-panel/history-gnome-run"
-#define PANEL_RUN_MAX_HISTORY 10
+#define PANEL_RUN_MAX_HISTORY 20
 
 static GtkTreeModel *
-_panel_run_get_recent_programs_list (void)
+_panel_run_get_recent_programs_list (PanelRunDialog *dialog)
 {
-	GtkListStore *list;
-	GSList       *gconf_items;
-	GSList       *command;
-	int           i = 0;
+	GtkListStore  *list;
+	char         **commands;
+	int            i;
 
 	list = gtk_list_store_new (1, G_TYPE_STRING);
 
-	gconf_items = gconf_client_get_list (panel_gconf_get_client (),
-					     PANEL_RUN_HISTORY_KEY,
-					     GCONF_VALUE_STRING, NULL);
+	commands = g_settings_get_strv (dialog->run_settings,
+					PANEL_RUN_HISTORY_KEY);
 
-	for (command = gconf_items;
-	     command && i < PANEL_RUN_MAX_HISTORY;
-	     command = command->next) {
+	for (i = 0; commands[i] != NULL; i++) {
 		GtkTreeIter iter;
 		gtk_list_store_prepend (list, &iter);
-		gtk_list_store_set (list, &iter, 0, command->data, -1);
-		i++;
+		gtk_list_store_set (list, &iter, 0, commands[i], -1);
 	}
 
-	g_slist_free (gconf_items);
+	g_strfreev (commands);
 
 	return GTK_TREE_MODEL (list);
 }
 
 static void
-_panel_run_save_recent_programs_list (GtkComboBox      *entry,
-				      char             *lastcommand)
+_panel_run_save_recent_programs_list (PanelRunDialog *dialog,
+				      char           *last_command)
 {
-	GtkTreeModel *model;
-	GtkTreeIter   iter;
-	GSList       *gconf_items = NULL;
-	int           i = 0;
+	char **commands;
+	char **new_commands;
+	int    i;
+	int    size;
 
-	gconf_items = g_slist_prepend (gconf_items, lastcommand);
-	i++;
+	commands = g_settings_get_strv (dialog->run_settings,
+					PANEL_RUN_HISTORY_KEY);
 
-	model = gtk_combo_box_get_model (GTK_COMBO_BOX (entry));
+	/* do not save the same command twice in a row */
+	if (g_strcmp0 (commands[0], last_command) == 0)
+		return;
 
-	if (gtk_tree_model_get_iter_first (model, &iter)) {
-		char *command;
+	for (i = 0; commands[i] != NULL; i++);
+	size = MIN (i + 1, PANEL_RUN_MAX_HISTORY);
 
-		do {
-			gtk_tree_model_get (model, &iter, 0, &command, -1);
+	new_commands = g_new (char *, size + 1);
 
-			if (strcmp (command, lastcommand) == 0)
-				continue;
+	new_commands[0] = last_command;
+	new_commands[size] = NULL; /* last item */
 
-			gconf_items = g_slist_prepend (gconf_items, command);
-			i++;
-		} while (gtk_tree_model_iter_next (model, &iter) &&
-			 i < PANEL_RUN_MAX_HISTORY);
-	}
+	for (i = 1; i < size; i++)
+		new_commands[i] = commands[i-1];
 
-	gconf_client_set_list (panel_gconf_get_client (),
-			       PANEL_RUN_HISTORY_KEY,
-			       GCONF_VALUE_STRING, gconf_items,
-			       NULL);
+	g_settings_set_strv (dialog->run_settings,
+			     PANEL_RUN_HISTORY_KEY,
+			     (const char **) new_commands);
 
-	g_slist_free (gconf_items);
+	g_free (new_commands); /* we don't own the strings */
+	g_strfreev (commands);
 }
 
 static void
@@ -191,7 +181,7 @@ panel_run_dialog_destroy (PanelRunDialog *dialog)
 	
 	dialog->changed_id = 0;
 
-	g_object_unref (dialog->program_list_box);
+	g_object_unref (dialog->list_expander);
 	
 	g_slist_foreach (dialog->add_icon_paths, (GFunc) gtk_tree_path_free, NULL);
 	g_slist_free (dialog->add_icon_paths);
@@ -216,11 +206,6 @@ panel_run_dialog_destroy (PanelRunDialog *dialog)
 		g_source_remove (dialog->find_command_idle_id);
 	dialog->find_command_idle_id = 0;
 
-	if (dialog->content_notify_id)
-		gconf_client_notify_remove (panel_gconf_get_client (),
-					    dialog->content_notify_id);
-	dialog->content_notify_id = 0;
-
 	if (dialog->dir_hash)
 		g_hash_table_destroy (dialog->dir_hash);
 	dialog->dir_hash = NULL;
@@ -240,7 +225,11 @@ panel_run_dialog_destroy (PanelRunDialog *dialog)
 	dialog->completion = NULL;
 
 	panel_run_dialog_disconnect_pixmap (dialog);
-	
+
+	if (dialog->run_settings)
+		g_object_unref (dialog->run_settings);
+	dialog->run_settings = NULL;
+
 	g_free (dialog);
 }
 
@@ -493,8 +482,7 @@ panel_run_dialog_execute (PanelRunDialog *dialog)
 		
 	if (result) {
 		/* only save working commands in history */
-		_panel_run_save_recent_programs_list
-			(GTK_COMBO_BOX (dialog->combobox), command);
+		_panel_run_save_recent_programs_list (dialog, command);
 		
 		/* only close the dialog if we successfully showed or launched
 		 * something */
@@ -1142,107 +1130,81 @@ panel_run_dialog_setup_program_list (PanelRunDialog *dialog,
 	GtkTreeSelection *selection;
 	
 	dialog->program_list = PANEL_GTK_BUILDER_GET (gui, "program_list");
-	dialog->program_list_box = PANEL_GTK_BUILDER_GET (gui, "program_list_box");
 	dialog->program_label = PANEL_GTK_BUILDER_GET (gui, "program_label");
 	dialog->main_box = PANEL_GTK_BUILDER_GET (gui, "main_box");
 	
-	/* Ref the box so it doesn't get destroyed when it is
-	 * removed from the visible area of the dialog box.
-	 */
-	g_object_ref (dialog->program_list_box);
-	
-	if (panel_profile_get_enable_program_list ()) {
-		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->program_list));
-		gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->program_list));
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 
-	        g_signal_connect (selection, "changed",
-				  G_CALLBACK (program_list_selection_changed),
-				  dialog);
+	g_signal_connect (selection, "changed",
+			  G_CALLBACK (program_list_selection_changed),
+			  dialog);
 
-	        g_signal_connect (dialog->program_list, "row-activated",
-				  G_CALLBACK (program_list_selection_activated),
-				  dialog);
-
-		/* start loading the list of applications */
-		dialog->add_items_idle_id = 
-			g_idle_add_full (G_PRIORITY_LOW, (GSourceFunc) panel_run_dialog_add_items_idle, 
-					 dialog, NULL);
-	}
-}
-
-static void
-panel_run_dialog_update_content (PanelRunDialog *dialog,
-				 gboolean        show_list)
-{
-	if (!panel_profile_get_enable_program_list ()) {
-		GtkWidget *parent;
-
-		parent = gtk_widget_get_parent (dialog->list_expander);
-		if (parent)
-			gtk_container_remove (GTK_CONTAINER (parent),
-					      dialog->list_expander);
-
-		gtk_window_set_resizable (GTK_WINDOW (dialog->run_dialog), FALSE);
-                gtk_widget_grab_focus (dialog->combobox);
-		
-	} else if (show_list) {
-		gtk_window_resize (GTK_WINDOW (dialog->run_dialog), 100, 300);
-		gtk_window_set_resizable (GTK_WINDOW (dialog->run_dialog), TRUE);
-		gtk_widget_grab_focus (dialog->program_list);
-		
-        } else if (!show_list) {
-		gtk_window_set_resizable (GTK_WINDOW (dialog->run_dialog), FALSE);
-                gtk_widget_grab_focus (dialog->combobox);
-        }
-}
-
-static void
-panel_run_dialog_content_notify (GConfClient    *client,
-				 int             notify_id,
-				 GConfEntry     *entry,
-				 PanelRunDialog *dialog)
-{
-	panel_run_dialog_update_content (dialog, gconf_value_get_bool (entry->value));
-}
-
-static void
-list_expander_toggled (GtkExpander    *expander,
-		       GParamSpec     *pspec,
-		       PanelRunDialog *dialog)
-{
-	panel_profile_set_show_program_list (gtk_expander_get_expanded (expander));
+	g_signal_connect (dialog->program_list, "row-activated",
+			  G_CALLBACK (program_list_selection_activated),
+			  dialog);
 }
 
 static void
 panel_run_dialog_setup_list_expander (PanelRunDialog *dialog,
 				      GtkBuilder     *gui)
 {
-	GConfClient *client;
-	const char *key;
-	
 	dialog->list_expander = PANEL_GTK_BUILDER_GET (gui, "list_expander");
 
-	if (panel_profile_get_enable_program_list ()) {
-		gtk_expander_set_expanded (GTK_EXPANDER (dialog->list_expander),
-					   panel_profile_get_show_program_list ());
+	/* Ref the expander so it doesn't get destroyed when it is
+	 * removed from the visible area of the dialog box. */
+	g_object_ref (dialog->list_expander);
 
-		if ( ! panel_profile_is_writable_show_program_list ())
-			gtk_widget_set_sensitive (dialog->list_expander, FALSE);
-		
-	        g_signal_connect (dialog->list_expander, "notify::expanded",
-				  G_CALLBACK (list_expander_toggled),
-				  dialog);
-	
-		client = panel_gconf_get_client ();
-		key = panel_gconf_general_key ("show_program_list");
-	
-		dialog->content_notify_id =
-			gconf_client_notify_add (client, key,
-						 (GConfClientNotifyFunc) panel_run_dialog_content_notify,
-						 dialog, NULL, NULL);
-					 
-		if (!dialog->content_notify_id)
-			g_warning ("error setting up content change notification");
+	g_settings_bind (dialog->run_settings,
+			 PANEL_RUN_SHOW_LIST_KEY,
+			 dialog->list_expander,
+			 "expanded",
+			 G_SETTINGS_BIND_DEFAULT);
+}
+
+static void
+panel_run_dialog_update_program_list (GSettings      *settings,
+				      char           *key,
+				      PanelRunDialog *dialog)
+{
+	gboolean   enabled;
+	gboolean   shown;
+	GtkWidget *parent;
+
+	enabled = g_settings_get_boolean (dialog->run_settings,
+					  PANEL_RUN_ENABLE_LIST_KEY);
+
+	parent = gtk_widget_get_parent (dialog->list_expander);
+
+	if (enabled) {
+		if (dialog->program_list_store == NULL) {
+			/* start loading the list of applications */
+			dialog->add_items_idle_id =
+				g_idle_add_full (G_PRIORITY_LOW,
+						 (GSourceFunc) panel_run_dialog_add_items_idle,
+						 dialog, NULL);
+		}
+
+		if (!parent)
+			gtk_box_pack_end (GTK_BOX (dialog->main_box),
+					  dialog->list_expander,
+					  TRUE, TRUE, 0);
+	} else {
+		if (parent)
+			gtk_container_remove (GTK_CONTAINER (parent),
+					      dialog->list_expander);
+	}
+
+	shown = g_settings_get_boolean (dialog->run_settings,
+					PANEL_RUN_SHOW_LIST_KEY);
+
+	if (enabled && shown) {
+		gtk_window_resize (GTK_WINDOW (dialog->run_dialog), 100, 300);
+		gtk_window_set_resizable (GTK_WINDOW (dialog->run_dialog), TRUE);
+		gtk_widget_grab_focus (dialog->program_list);
+        } else {
+		gtk_window_set_resizable (GTK_WINDOW (dialog->run_dialog), FALSE);
+                gtk_widget_grab_focus (dialog->combobox);
 	}
 }
 
@@ -1521,7 +1483,8 @@ entry_event (GtkEditable    *entry,
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->program_list));
 	gtk_tree_selection_unselect_all (selection);
 
-	if (!panel_profile_get_enable_autocompletion ())
+	if (!g_settings_get_boolean (dialog->run_settings,
+				     PANEL_RUN_ENABLE_COMPLETION_KEY))
 		return FALSE;
 
 	/* tab completion */
@@ -1617,9 +1580,13 @@ static void
 combobox_changed (GtkComboBox    *combobox,
 		  PanelRunDialog *dialog)
 {
-	char *text;
-	char *start;
-	char *msg;
+	gboolean  program_list_enabled;
+	char     *text;
+	char     *start;
+	char     *msg;
+
+	program_list_enabled = g_settings_get_boolean (dialog->run_settings,
+						       PANEL_RUN_ENABLE_LIST_KEY);
 
         text = g_strdup (panel_run_dialog_get_combo_text (dialog));
 
@@ -1646,7 +1613,7 @@ combobox_changed (GtkComboBox    *combobox,
 		gtk_widget_set_sensitive (dialog->run_button, FALSE);
 		gtk_drag_source_unset (dialog->run_dialog);
 
-		if (panel_profile_get_enable_program_list ())
+		if (program_list_enabled)
 			gtk_label_set_text (GTK_LABEL (dialog->program_label),
 					    _("Select an application to view its description."));
 
@@ -1657,7 +1624,7 @@ combobox_changed (GtkComboBox    *combobox,
 			dialog->find_command_idle_id = 0;
 		}
 
-		if (panel_profile_get_enable_program_list ()) {
+		if (program_list_enabled) {
 			GtkTreeIter  iter;
 			GtkTreePath *path;
 
@@ -1684,7 +1651,7 @@ combobox_changed (GtkComboBox    *combobox,
 			     GDK_ACTION_COPY);
 	gtk_drag_source_add_uri_targets (dialog->run_dialog);
 
-	if (panel_profile_get_enable_program_list () &&
+	if (program_list_enabled &&
 	    !dialog->use_program_list) {
 		msg = g_strdup_printf (_("Will run command: '%s'"),
 				       start);
@@ -1693,7 +1660,7 @@ combobox_changed (GtkComboBox    *combobox,
 	}
 	
 	/* look up icon for the command */
-	if (panel_profile_get_enable_program_list () &&
+	if (program_list_enabled &&
 	    !dialog->use_program_list &&
 	    !dialog->find_command_idle_id)
 		dialog->find_command_idle_id =
@@ -1764,7 +1731,7 @@ panel_run_dialog_setup_entry (PanelRunDialog *dialog,
 	gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
 
 	gtk_combo_box_set_model (GTK_COMBO_BOX (dialog->combobox),
-				 _panel_run_get_recent_programs_list ());
+				 _panel_run_get_recent_programs_list (dialog));
 	gtk_combo_box_set_entry_text_column
 		(GTK_COMBO_BOX (dialog->combobox), 0);
 
@@ -1949,6 +1916,8 @@ panel_run_dialog_new (GdkScreen  *screen,
 	dialog = g_new0 (PanelRunDialog, 1);
 
 	dialog->run_dialog = PANEL_GTK_BUILDER_GET (gui, "panel_run_dialog");
+
+	dialog->run_settings = g_settings_new (PANEL_RUN_SCHEMA);
 	
 	g_signal_connect_swapped (dialog->run_dialog, "response",
 				  G_CALLBACK (panel_run_dialog_response), dialog);
@@ -1967,7 +1936,12 @@ panel_run_dialog_new (GdkScreen  *screen,
 
 	panel_run_dialog_set_default_icon    (dialog, FALSE);
 
-	panel_run_dialog_update_content (dialog, panel_profile_get_show_program_list ());
+	g_signal_connect (dialog->run_settings, "changed::"PANEL_RUN_ENABLE_LIST_KEY,
+			  G_CALLBACK (panel_run_dialog_update_program_list), dialog);
+	g_signal_connect (dialog->run_settings, "changed::"PANEL_RUN_SHOW_LIST_KEY,
+			  G_CALLBACK (panel_run_dialog_update_program_list), dialog);
+
+	panel_run_dialog_update_program_list (dialog->run_settings, NULL, dialog);
 
 	gtk_widget_set_sensitive (dialog->run_button, FALSE);
 	
@@ -2010,7 +1984,7 @@ panel_run_dialog_present (GdkScreen *screen,
 	GtkBuilder *gui;
 	GError     *error;
 
-	if (panel_lockdown_get_disable_command_line ())
+	if (panel_lockdown_get_disable_command_line_s ())
 		return;
 
 	if (static_dialog) {
