@@ -76,6 +76,7 @@ GType                panel_toplevel_get_type               (void) G_GNUC_CONST;
 
 PanelWidget         *panel_toplevel_get_panel_widget       (PanelToplevel       *toplevel);
 
+G_CONST_RETURN char *panel_toplevel_get_id                 (PanelToplevel       *toplevel);
 void                 panel_toplevel_set_name               (PanelToplevel       *toplevel,	
 							    const char          *name);
 G_CONST_RETURN char *panel_toplevel_get_name               (PanelToplevel       *toplevel);
@@ -117,14 +118,6 @@ int                  panel_toplevel_get_monitor            (PanelToplevel
 void                 panel_toplevel_rotate                 (PanelToplevel       *toplevel,
 							    gboolean             clockwise);
 
-void                 panel_toplevel_attach_to_widget       (PanelToplevel       *toplevel,
-							    PanelToplevel       *attach_toplevel,
-							    GtkWidget           *attach_widget);
-void                 panel_toplevel_detach                 (PanelToplevel       *toplevel);
-gboolean             panel_toplevel_get_is_attached        (PanelToplevel       *toplevel);
-PanelToplevel       *panel_toplevel_get_attach_toplevel    (PanelToplevel       *toplevel);
-GtkWidget           *panel_toplevel_get_attach_widget      (PanelToplevel       *toplevel);
-
 gboolean             panel_toplevel_get_is_floating	   (PanelToplevel       *toplevel);
 
 gboolean             panel_toplevel_get_is_hidden          (PanelToplevel       *toplevel);
@@ -150,8 +143,6 @@ void                 panel_toplevel_set_unhide_delay       (PanelToplevel
 							    int                  unhide_delay);
 int                  panel_toplevel_get_unhide_delay       (PanelToplevel       *toplevel);
 
-void                 panel_toplevel_set_animate            (PanelToplevel       *toplevel,
-							    gboolean             animate);
 gboolean             panel_toplevel_get_animate            (PanelToplevel       *toplevel);
 void                 panel_toplevel_set_animation_speed    (PanelToplevel       *toplevel,
 							    PanelAnimationSpeed  animation_speed);
@@ -165,10 +156,15 @@ void                 panel_toplevel_set_enable_arrows      (PanelToplevel
 gboolean             panel_toplevel_get_enable_arrows      (PanelToplevel       *toplevel);
 void                 panel_toplevel_update_edges           (PanelToplevel       *toplevel);
 
-gboolean             panel_toplevel_is_last_unattached     (PanelToplevel       *toplevel);
+gboolean             panel_toplevel_is_last                (PanelToplevel       *toplevel);
 int                  panel_toplevel_get_minimum_size       (PanelToplevel *toplevel);
 int                  panel_toplevel_get_maximum_size       (PanelToplevel *toplevel);
+
 GSList              *panel_toplevel_list_toplevels         (void);
+PanelToplevel       *panel_toplevel_get_by_id              (const char    *toplevel_id);
+gboolean             panel_toplevel_find_empty_spot        (GdkScreen        *screen,
+							    PanelOrientation *orientation,
+							    int              *monitor);
 
 G_END_DECLS
 
