@@ -1117,9 +1117,12 @@ panel_util_key_event_is_binding (GdkEventKey *event,
 	GtkBindingEntry *binding_entry;
 	gboolean         popup = FALSE;
 	gboolean         popup_modifier = FALSE;
+	guint            modifiers;
 	char            *signal_dash;
 	char            *signal_underscore;
 
+	modifiers = event->state & gtk_accelerator_get_default_mod_mask ();
+
 	signal_dash = g_strdup (signal_name);
 	g_strdelimit (signal_dash, "_", '-');
 	signal_underscore = g_strdup (signal_name);
@@ -1140,8 +1143,8 @@ panel_util_key_event_is_binding (GdkEventKey *event,
 				if (binding_entry->keyval != event->keyval)
 					break;
 
-				popup = (event->state & GDK_MODIFIER_MASK) == binding_entry->modifiers;
-				popup_modifier = (event->state & GDK_MODIFIER_MASK) == (panel_bindings_get_mouse_button_modifier_keymask ()|binding_entry->modifiers);
+				popup = modifiers == binding_entry->modifiers;
+				popup_modifier = modifiers == (panel_bindings_get_mouse_button_modifier_keymask ()|binding_entry->modifiers);
 				break;
 			}
 		}
@@ -1176,3 +1179,21 @@ panel_util_key_event_is_popup_panel (GdkEventKey *event,
 	panel_util_key_event_is_binding (event, PANEL_TYPE_TOPLEVEL, "popup-panel-menu",
 					 is_popup, is_popup_modifier);
 }
+
+char *
+panel_util_get_user_name (void)
+{
+	char *name;
+
+	name = g_locale_to_utf8 (g_get_real_name (), -1, NULL, NULL, NULL);
+
+	if (PANEL_GLIB_STR_EMPTY (name) || g_strcmp0 (name, "Unknown") == 0) {
+		g_free (name);
+		name = g_locale_to_utf8 (g_get_user_name (), -1 , NULL, NULL, NULL);
+	}
+
+	if (!name)
+		name = g_strdup (g_get_user_name ());
+
+	return name;
+}
