@@ -363,7 +363,7 @@ panel_button_press_event (PanelToplevel  *toplevel,
 	if (event->button != 3)
 		return FALSE;
 
-	modifiers = event->state & GDK_MODIFIER_MASK;
+	modifiers = event->state & gtk_accelerator_get_default_mod_mask ();
 
 	if (modifiers == panel_bindings_get_mouse_button_modifier_keymask ())
 		return panel_popup_menu (toplevel, event->button, event->time);
@@ -868,14 +868,13 @@ move_applet (PanelWidget         *panel,
 
 	info = g_slist_nth_data (applet_list, applet_index);
 
-	if ( ! panel_applet_can_freely_move (info))
+	if (info == NULL || info->widget == NULL ||
+	    !panel_applet_can_freely_move (info))
 		return FALSE;
 
 	parent = gtk_widget_get_parent (info->widget);
 
-	if (info != NULL &&
-	    info->widget != NULL &&
-	    parent != NULL &&
+	if (parent != NULL &&
 	    PANEL_IS_WIDGET (parent)) {
 		panel_widget_reparent (PANEL_WIDGET (parent),
 				       panel,
