@@ -89,6 +89,7 @@ struct _PanelAppletPrivate {
 	GClosure          *closure;
 	char              *object_path;
 	guint              object_id;
+	char              *settings_path;
 	char              *prefs_key;
 
 	GtkUIManager      *ui_manager;
@@ -109,7 +110,6 @@ struct _PanelAppletPrivate {
 
 	gboolean           moving_focus_out;
 
-	gboolean           locked;
 	gboolean           locked_down;
 };
 
@@ -128,13 +128,13 @@ enum {
 	PROP_ID,
 	PROP_CLOSURE,
 	PROP_CONNECTION,
+	PROP_SETTINGS_PATH,
 	PROP_PREFS_KEY,
 	PROP_ORIENT,
 	PROP_SIZE,
 	PROP_BACKGROUND,
 	PROP_FLAGS,
 	PROP_SIZE_HINTS,
-	PROP_LOCKED,
 	PROP_LOCKED_DOWN
 };
 
@@ -146,8 +146,6 @@ static void       panel_applet_menu_cmd_remove     (GtkAction         *action,
 						    PanelApplet       *applet);
 static void       panel_applet_menu_cmd_move       (GtkAction         *action,
 						    PanelApplet       *applet);
-static void       panel_applet_menu_cmd_lock       (GtkAction         *action,
-						    PanelApplet       *applet);
 static void       panel_applet_register_object     (PanelApplet       *applet);
 
 static const gchar panel_menu_ui[] =
@@ -156,10 +154,8 @@ static const gchar panel_menu_ui[] =
 	"    <placeholder name=\"AppletItems\"/>\n"
 	"  </popup>\n"
 	"  <popup name=\"PanelAppletEditPopup\" action=\"PopupEditAction\">\n"
-	"    <menuitem name=\"RemoveItem\" action=\"Remove\"/>\n"
 	"    <menuitem name=\"MoveItem\" action=\"Move\"/>\n"
-	"    <separator/>\n"
-	"    <menuitem name=\"LockItem\" action=\"Lock\"/>\n"
+	"    <menuitem name=\"RemoveItem\" action=\"Remove\"/>\n"
 	"  </popup>\n"
 	"</ui>\n";
 
@@ -175,12 +171,6 @@ static const GtkActionEntry menu_entries[] = {
 	  G_CALLBACK (panel_applet_menu_cmd_move) }
 };
 
-static const GtkToggleActionEntry menu_toggle_entries[] = {
-	{ "Lock", NULL, N_("Loc_k To Panel"),
-	  NULL, NULL,
-	  G_CALLBACK (panel_applet_menu_cmd_lock) }
-};
-
 G_DEFINE_TYPE (PanelApplet, panel_applet, GTK_TYPE_EVENT_BOX)
 
 #define PANEL_APPLET_INTERFACE   "org.gnome.panel.applet.Applet"
@@ -300,6 +290,8 @@ panel_applet_associate_schemas_in_dir (GConfClient  *client,
  * defined in @schema_dir. This must be called if the applet will save
  * per-instance settings, to ensure that each key in the per-instance GConf
  * directory has a defined type, sane default and documentation.
+ *
+ * Deprecated: 3.0: Use #GSettings to store per-instance settings.
  **/
 void
 panel_applet_add_preferences (PanelApplet  *applet,
@@ -337,6 +329,8 @@ panel_applet_add_preferences (PanelApplet  *applet,
  * Gets the GConf path to the per-instance settings of @applet.
  *
  * Returns: a copy of the GConf path to the per-instance settings of @applet.
+ *
+ * Deprecated: 3.0: Use #GSettings to store per-instance settings.
  **/
 char *
 panel_applet_get_preferences_key (PanelApplet *applet)
@@ -380,6 +374,48 @@ panel_applet_set_preferences_key (PanelApplet *applet,
 	g_object_notify (G_OBJECT (applet), "prefs-key");
 }
 
+/**
+ * panel_applet_settings_new:
+ * @applet: a #PanelApplet.
+ * @schema: the name of the schema.
+ *
+ * Creates a new #GSettings object for the per-instance settings of @applet,
+ * with a given schema.
+ *
+ * Returns: a new #GSettings object for the per-instance settings of @applet.
+ **/
+GSettings *
+panel_applet_settings_new (PanelApplet *applet,
+			   const char  *schema)
+{
+	g_return_val_if_fail (PANEL_IS_APPLET (applet), NULL);
+	g_return_val_if_fail (schema != NULL, NULL);
+
+	if (!applet->priv->settings_path)
+		return NULL;
+
+	return g_settings_new_with_path (schema, applet->priv->settings_path);
+}
+
+static void
+panel_applet_set_settings_path (PanelApplet *applet,
+				const char  *settings_path)
+{
+	if (applet->priv->settings_path == settings_path)
+		return;
+
+	if (g_strcmp0 (applet->priv->settings_path, settings_path) == 0)
+		return;
+
+	g_free (applet->priv->settings_path);
+	applet->priv->settings_path = NULL;
+
+	if (settings_path)
+		applet->priv->settings_path = g_strdup (settings_path);
+
+	g_object_notify (G_OBJECT (applet), "settings-path");
+}
+
 /**
  * panel_applet_get_flags:
  * @applet: a #PanelApplet.
@@ -628,62 +664,6 @@ panel_applet_set_orient (PanelApplet      *applet,
 	g_object_notify (G_OBJECT (applet), "orient");
 }
 
-#if 0
-/* Locked should not be public API: it's not useful for applet writers to know
- * if the applet is locked (as opposed to locked_down). */
-static gboolean
-panel_applet_get_locked (PanelApplet *applet)
-{
-	g_return_val_if_fail (PANEL_IS_APPLET (applet), FALSE);
-
-	return applet->priv->locked;
-}
-#endif
-
-static void
-panel_applet_set_locked (PanelApplet *applet,
-			 gboolean     locked)
-{
-	GtkAction *action;
-
-	g_return_if_fail (PANEL_IS_APPLET (applet));
-
-	if (applet->priv->locked == locked)
-		return;
-
-	applet->priv->locked = locked;
-
-	action = panel_applet_menu_get_action (applet, "Lock");
-	g_signal_handlers_block_by_func (action,
-					 panel_applet_menu_cmd_lock,
-					 applet);
-	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), locked);
-	g_signal_handlers_unblock_by_func (action,
-					   panel_applet_menu_cmd_lock,
-					   applet);
-
-	panel_applet_menu_update_actions (applet);
-
-	g_object_notify (G_OBJECT (applet), "locked");
-
-	if (applet->priv->connection) {
-		GError *error = NULL;
-
-		g_dbus_connection_emit_signal (applet->priv->connection,
-					       NULL,
-					       applet->priv->object_path,
-					       PANEL_APPLET_INTERFACE,
-					       locked ? "Lock" : "Unlock",
-					       NULL, &error);
-		if (error) {
-			g_printerr ("Failed to send signal %s: %s\n",
-				    locked ? "Lock" : "Unlock",
-				    error->message);
-			g_error_free (error);
-		}
-	}
-}
-
 /**
  * panel_applet_get_locked_down:
  * @applet: a #PanelApplet.
@@ -871,17 +851,12 @@ panel_applet_menu_get_action (PanelApplet *applet,
 static void
 panel_applet_menu_update_actions (PanelApplet *applet)
 {
-	gboolean locked = applet->priv->locked;
 	gboolean locked_down = applet->priv->locked_down;
 
-	g_object_set (panel_applet_menu_get_action (applet, "Lock"),
-		      "visible", !locked_down, NULL);
 	g_object_set (panel_applet_menu_get_action (applet, "Move"),
-		      "sensitive", !locked,
 		      "visible", !locked_down,
 		      NULL);
 	g_object_set (panel_applet_menu_get_action (applet, "Remove"),
-		      "sensitive", !locked,
 		      "visible", !locked_down,
 		      NULL);
 }
@@ -930,16 +905,6 @@ panel_applet_menu_cmd_move (GtkAction   *action,
 	}
 }
 
-static void
-panel_applet_menu_cmd_lock (GtkAction   *action,
-			    PanelApplet *applet)
-{
-	gboolean locked;
-
-	locked = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	panel_applet_set_locked (applet, locked);
-}
-
 /**
  * panel_applet_setup_menu:
  * @applet: a #PanelApplet.
@@ -1059,6 +1024,7 @@ panel_applet_finalize (GObject *object)
 
 	g_free (applet->priv->size_hints);
 	g_free (applet->priv->prefs_key);
+	g_free (applet->priv->settings_path);
 	g_free (applet->priv->background);
 	g_free (applet->priv->id);
 
@@ -1300,7 +1266,7 @@ panel_applet_button_press (GtkWidget      *widget,
 	if (event->button == 3) {
 		guint modifiers;
 
-		modifiers = event->state & GDK_MODIFIER_MASK;
+		modifiers = event->state & gtk_accelerator_get_default_mod_mask ();
 
 		if (modifiers == panel_applet_bindings_get_mouse_button_modifier_keymask ())
 			panel_applet_edit_menu_popup (applet, event->button, event->time);
@@ -1849,6 +1815,9 @@ panel_applet_get_property (GObject    *object,
 	case PROP_CONNECTION:
 		g_value_set_object (value, applet->priv->connection);
 		break;
+	case PROP_SETTINGS_PATH:
+		g_value_set_string (value, applet->priv->settings_path);
+		break;
 	case PROP_PREFS_KEY:
 		g_value_set_string (value, applet->priv->prefs_key);
 		break;
@@ -1878,9 +1847,6 @@ panel_applet_get_property (GObject    *object,
 		g_value_set_pointer (value, variant);
 	}
 		break;
-	case PROP_LOCKED:
-		g_value_set_boolean (value, applet->priv->locked);
-		break;
 	case PROP_LOCKED_DOWN:
 		g_value_set_boolean (value, applet->priv->locked_down);
 		break;
@@ -1913,6 +1879,9 @@ panel_applet_set_property (GObject      *object,
 	case PROP_CONNECTION:
 		applet->priv->connection = g_value_dup_object (value);
 		break;
+	case PROP_SETTINGS_PATH:
+		panel_applet_set_settings_path (applet, g_value_get_string (value));
+		break;
 	case PROP_PREFS_KEY:
 		panel_applet_set_preferences_key (applet, g_value_get_string (value));
 		break;
@@ -1937,9 +1906,6 @@ panel_applet_set_property (GObject      *object,
 		panel_applet_set_size_hints (applet, size_hints, n_elements, 0);
 	}
 		break;
-	case PROP_LOCKED:
-		panel_applet_set_locked (applet, g_value_get_boolean (value));
-		break;
 	case PROP_LOCKED_DOWN:
 		panel_applet_set_locked_down (applet, g_value_get_boolean (value));
 		break;
@@ -2022,10 +1988,6 @@ panel_applet_init (PanelApplet *applet)
 				      menu_entries,
 				      G_N_ELEMENTS (menu_entries),
 				      applet);
-	gtk_action_group_add_toggle_actions (applet->priv->panel_action_group,
-					     menu_toggle_entries,
-					     G_N_ELEMENTS (menu_toggle_entries),
-					     applet);
 
 	applet->priv->ui_manager = gtk_ui_manager_new ();
 	gtk_ui_manager_insert_action_group (applet->priv->ui_manager,
@@ -2127,12 +2089,28 @@ panel_applet_class_init (PanelAppletClass *klass)
 							      G_TYPE_DBUS_CONNECTION,
 							      G_PARAM_CONSTRUCT_ONLY |
 							      G_PARAM_READWRITE));
+	/**
+	 * PanelApplet:settings-path:
+	 *
+	 * The GSettings path to the per-instance settings of the applet.
+	 *
+	 * This property gets set when the applet gets embedded.
+	 **/
+	g_object_class_install_property (gobject_class,
+					 PROP_SETTINGS_PATH,
+					 g_param_spec_string ("settings-path",
+							      "SettingsPath",
+							      "GSettings path to per-instance settings",
+							      NULL,
+							      G_PARAM_READWRITE));
 	/**
 	 * PanelApplet:prefs-key:
 	 *
 	 * The GConf path to the per-instance settings of the applet.
 	 *
 	 * This property gets set when the applet gets embedded.
+	 *
+	 * Deprecated: 3.0: Use #GSettings to store per-instance settings.
 	 **/
 	g_object_class_install_property (gobject_class,
 					 PROP_PREFS_KEY,
@@ -2215,18 +2193,6 @@ panel_applet_class_init (PanelAppletClass *klass)
 							       "SizeHints",
 							       "Size hints of the applet",
 							       G_PARAM_READWRITE));
-	/**
-	 * PanelApplet:locked:
-	 *
-	 * Whether the position of the applet is locked.
-	 **/
-	g_object_class_install_property (gobject_class,
-					 PROP_LOCKED,
-					 g_param_spec_boolean ("locked",
-							       "Locked",
-							       "Whether the position of the applet is locked",
-							       FALSE,
-							       G_PARAM_READWRITE));
 	/**
 	 * PanelApplet:locked-down:
 	 *
@@ -2369,7 +2335,10 @@ get_property_cb (GDBusConnection *connection,
 	PanelApplet *applet = PANEL_APPLET (user_data);
 	GVariant    *retval = NULL;
 
-	if (g_strcmp0 (property_name, "PrefsKey") == 0) {
+	if (g_strcmp0 (property_name, "SettingsPath") == 0) {
+		retval = g_variant_new_string (applet->priv->settings_path ?
+					       applet->priv->settings_path : "");
+	} else if (g_strcmp0 (property_name, "PrefsKey") == 0) {
 		retval = g_variant_new_string (applet->priv->prefs_key ?
 					       applet->priv->prefs_key : "");
 	} else if (g_strcmp0 (property_name, "Orient") == 0) {
@@ -2391,8 +2360,6 @@ get_property_cb (GDBusConnection *connection,
 		retval = g_variant_new_array (G_VARIANT_TYPE_INT32,
 					      children, applet->priv->size_hints_len);
 		g_free (children);
-	} else if (g_strcmp0 (property_name, "Locked") == 0) {
-		retval = g_variant_new_boolean (applet->priv->locked);
 	} else if (g_strcmp0 (property_name, "LockedDown") == 0) {
 		retval = g_variant_new_boolean (applet->priv->locked_down);
 	}
@@ -2412,7 +2379,9 @@ set_property_cb (GDBusConnection *connection,
 {
 	PanelApplet *applet = PANEL_APPLET (user_data);
 
-	if (g_strcmp0 (property_name, "PrefsKey") == 0) {
+	if (g_strcmp0 (property_name, "SettingsPath") == 0) {
+		panel_applet_set_settings_path (applet, g_variant_get_string (value, NULL));
+	} else if (g_strcmp0 (property_name, "PrefsKey") == 0) {
 		panel_applet_set_preferences_key (applet, g_variant_get_string (value, NULL));
 	} else if (g_strcmp0 (property_name, "Orient") == 0) {
 		panel_applet_set_orient (applet, g_variant_get_uint32 (value));
@@ -2428,8 +2397,6 @@ set_property_cb (GDBusConnection *connection,
 
 		size_hints = g_variant_get_fixed_array (value, &n_elements, sizeof (gint32));
 		panel_applet_set_size_hints (applet, size_hints, n_elements, 0);
-	} else if (g_strcmp0 (property_name, "Locked") == 0) {
-		panel_applet_set_locked (applet, g_variant_get_boolean (value));
 	} else if (g_strcmp0 (property_name, "LockedDown") == 0) {
 		panel_applet_set_locked_down (applet, g_variant_get_boolean (value));
 	}
@@ -2448,18 +2415,16 @@ static const gchar introspection_xml[] =
 	      "<arg name='button' type='u' direction='in'/>"
 	      "<arg name='time' type='u' direction='in'/>"
 	    "</method>"
+	    "<property name='SettingsPath' type='s' access='readwrite'/>"
 	    "<property name='PrefsKey' type='s' access='readwrite'/>"
 	    "<property name='Orient' type='u' access='readwrite' />"
 	    "<property name='Size' type='u' access='readwrite'/>"
 	    "<property name='Background' type='s' access='readwrite'/>"
 	    "<property name='Flags' type='u' access='readwrite'/>"
 	    "<property name='SizeHints' type='ai' access='readwrite'/>"
-	    "<property name='Locked' type='b' access='readwrite'/>"
 	    "<property name='LockedDown' type='b' access='readwrite'/>"
 	    "<signal name='Move' />"
 	    "<signal name='RemoveFromPanel' />"
-	    "<signal name='Lock' />"
-	    "<signal name='Unlock' />"
 	  "</interface>"
 	"</node>";
 
